@@ -39,6 +39,7 @@ namespace Gwenview
 
 class AbstractDocumentInfoProvider;
 class AbstractThumbnailViewHelper;
+class ThumbnailProvider;
 
 struct ThumbnailViewPrivate;
 class GWENVIEWLIB_EXPORT ThumbnailView : public QListView
@@ -97,6 +98,8 @@ public:
 
     virtual void setModel(QAbstractItemModel* model);
 
+    void setThumbnailProvider(ThumbnailProvider* thumbnailProvider);
+
     /**
      * Publish this method so that delegates can call it.
      */
@@ -152,6 +155,8 @@ public Q_SLOTS:
 
     void scrollToSelectedIndex();
 
+    void generateThumbnailsForItems();
+
 protected:
     virtual void dragEnterEvent(QDragEnterEvent*);
 
@@ -180,7 +185,7 @@ protected Q_SLOTS:
 private Q_SLOTS:
     void showContextMenu();
     void emitIndexActivatedIfNoModifiers(const QModelIndex&);
-    void setThumbnail(const KFileItem&, const QPixmap&, const QSize&);
+    void setThumbnail(const KFileItem&, const QPixmap&, const QSize&, qulonglong fileSize);
     void setBrokenThumbnail(const KFileItem&);
 
     /**
@@ -198,7 +203,6 @@ private Q_SLOTS:
      */
     void updateBusyIndexes();
 
-    void generateThumbnailsForVisibleItems();
     void smoothNextThumbnail();
 
 private:
